package org.jbjf.tasks.test;

import java.util.ArrayList;
import java.util.HashMap;

import org.jbjf.core.AbstractTask;
import org.jbjf.plugin.IJBJFPluginCipher;
import org.jbjf.plugin.IJBJFPluginDatabase;
import org.jbjf.xml.JBJFDatabaseConnection;
import org.jbjf.xml.JBJFPluginDefinition;

/**
 * The <code>MyCipherTask001</code> class provides ...
 * <p>
 * <h3>Dependencies:</h3>
 * <ul>
 * <li>JBJF 1.x.x(+)
 * </ul>
 * <h3>Resources:</h3>
 * <code>MyCipherTask001</code> depends on the following &lt;resource&gt; 
 * elements to function correctly:
 * <ul>
 * <li>type1 - The &lt;sql-definition&gt; in the JBJF Batch
 * Definition file to use as the SQL for the loading effort.
 * </ul>
 * <p>
 * <h3>Details</h3>
 * <hr>
 * <h4>Input Resources</h4>
 * <table border='1' width='65%'>
 * <thead>
 *  <tr>
 *      <td width='15%'>Location</td>
 *      <td width='1%'>&nbsp;</td>
 *      <td width='15%'>Id/Name</td>
 *      <td width='1%'>&nbsp;</td>
 *      <td width='25%'>Type</td>
 *      <td width='1%'>&nbsp;</td>
 *      <td width='10%'>Required</td>
 *      <td width='1%'>&nbsp;</td>
 *      <td>Description/Comments</td>
 *  </tr>
 * </thead>
 *  <tr valign='top'>
 *      <td>&lt;task&gt;</td>
 *      <td>&nbsp;</td>
 *      <td>source</td>
 *      <td>&nbsp;</td>
 *      <td>String</td>
 *      <td>&nbsp;</td>
 *      <td>True</td>
 *      <td>&nbsp;</td>
 *      <td>Full or partial ...
 *      </td>
 *  </tr>
 *  <tr valign='top'>
 *      <td>&lt;task&gt;</td>
 *      <td>&nbsp;</td>
 *      <td>target</td>
 *      <td>&nbsp;</td>
 *      <td>String</td>
 *      <td>&nbsp;</td>
 *      <td>True</td>
 *      <td>&nbsp;</td>
 *      <td>Full or partial...
 *      </td>
 *  </tr>
 *  <tr valign='top'>
 *      <td>&lt;task&gt;</td>
 *      <td>&nbsp;</td>
 *      <td>filter</td>
 *      <td>&nbsp;</td>
 *      <td>String</td>
 *      <td>&nbsp;</td>
 *      <td>True</td>
 *      <td>&nbsp;</td>
 *      <td>A filename...
 *      </td>
 *  </tr>
 * </table>
 * <p>
 * The following is an example XML &lt;task&gt; element:
 * <p>
 * <pre>
 *         &lt;task name="t023" order="23" active="true"&gt;
 *             &lt;class&gt;org.jbjf.tasks.MyCipherTask001&lt;/class&gt;
 *             &lt;resource type="sql-definition"&gt;insert-windows-midrange-portfolio&lt;/resource&gt;
 *             &lt;resource type="connection"&gt;eam-rpt&lt;/resource&gt;
 *             &lt;resource type="job-stack-key"&gt;windows-midrange-hw-portfolio&lt;/resource&gt;
 *             &lt;resource type="truncate"&gt;windows_midrange_hw_portfolio&lt;/resource&gt;
 *         &lt;/task&gt;
 * </pre>
 * <p>
 * @author  Adym S. Lincoln<br>
 * Copyright (C) 2007. Adym S. Lincoln All rights reserved.
 * @version 1.0.0
 * @since   1.0.0
 */

public class MyCipherTask001 extends AbstractTask {
    /** 
     * Stores a fully qualified class name.  Used for debugging and 
     * auditing.
     * @since 1.0.0
     */
    public static final String ID = MyCipherTask001.class.getName();

    /** 
     * Stores the class name, primarily used for debugging and so 
     * forth.  Used for debugging and auditing.
     * @since 1.0.0
     */
    private String SHORT_NAME = "MyCipherTask001()";

    /** 
     * Stores a <code>SYSTEM IDENTITY HASHCODE</code>.  Used for
     * debugging and auditing.
     * @since 1.0.0
     */
    private String SYSTEM_IDENTITY = String.valueOf( System.identityHashCode( this ) );

    /**
     * Default constructor.
     */
    public MyCipherTask001() {
        mtaskRequired = new ArrayList();
        getRequiredResources().add( "plugin-cipher" );
    }

    /* (non-Javadoc)
     * @see org.jbjf.core.AbstractTask#runTask(java.util.HashMap)
     */
    @Override
    public void runTask( HashMap arg0 ) throws Exception {
        getLog().debug( SHORT_NAME + " ... Start ..." );

        if ( hasRequiredResources() ) {
            // Grab the <plugin-definition>, has the id...
            JBJFPluginDefinition    lpluginCipher = (JBJFPluginDefinition)getResources().get(
                "plugin-cipher"
            );
            
            // RUNTIME PLUGINS : 
            // Grab the runtime plugin from the task cache...
            IJBJFPluginCipher   theCipher = getTaskPlugins().getCipherPlugin(lpluginCipher.getPluginId());
            
            getLog().debug("Plugin ID.........[" + theCipher.getPluginId() + "]" );
            getLog().debug("Plugin Cipher Key.[" + theCipher.getCipherKey() + "]" );
            getLog().debug("Plugin Name.......[" + theCipher.getPluginName() + "]" );
            getLog().debug("Plugin Type.......[" + theCipher.getPluginType() + "]" );
            getLog().debug("Plugin Active.....[" + theCipher.getPluginActive() + "]" );
            
            getLog().debug("Decrypt Call......[" + theCipher.decryptString("MyTaskCipher001 decrypt call") + "]" );
            getLog().debug("Encrypt Call......[" + theCipher.encryptString("MyTaskCipher001 encrypt call") + "]" );
        }

        getLog().debug( SHORT_NAME + " ... Complete ..." );
    }
}

